package main

import (
	"fmt"
	"log"
	"time"
)

type Config struct {
	Port         int
	AuthCode     string
	PeerID       string
	Peers        []string
	Domain       string
	NodesEnabled bool
}

var defaultConfig = Config{
	Port:     5000,
	Domain:   "localhost",
	Peers:    []string{},
	AuthCode: generateStrongRandomString(64),
}

const configFilePath = "config.ini"

var config Config

func main() {
	err := initConfig()
	if err != nil {
		fmt.Println("Error during initialization:", err)
		return
	}

	loadNodeConfig()
	go startFileWatcher()
	go checkMasterHeartbeat()

	if config.AuthCode == "" {
		config.AuthCode = generateStrongRandomString(64)
		fmt.Printf("Generated connection code: %s\n", config.AuthCode)
		saveConfig(config)
	}

	// Generate Host ID
	hostID, nodeErr := generateHostID()
	if nodeErr != nil {
		log.Fatalf("Failed to generate host ID: %v", nodeErr)
	}
	config.PeerID = hostID

	if len(config.Peers) > 0 {
		time.Sleep(2 * time.Second) // Give some time for connections to establish
		startElection()
	}

	go startNodeClient()

	runServer()
}
